<?php

namespace BrightRiver\Rendered\Block;

use Magento\Framework\View\Element\Template\Context;
use Magento\Framework\View\Element\Template;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\ScopeInterface;

/**
 * The modal that renders the 3D view.
 *
 * @since 1.0.0
 */
class Modal extends Template
{
    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * @var null|string
     */
    private $_popupWidth = null;

    /**
     * @var null|string
     */
    private $_popupHeight = null;

    /**
     * @var null|string
     */
    private $_bgColor = null;

    /**
     * Modal constructor.
     *
     * @param Context $context
     * @param ScopeConfigInterface $scopeConfig
     * @param array $data
     */
    public function __construct(
        Context $context,
        ScopeConfigInterface $scopeConfig,
        array $data = []
    ) {
        $this->scopeConfig = $scopeConfig;
        parent::__construct($context, $data);
    }

    /**
     * Get the configured popup width
     *
     * @return string|null
     */
    public function getPopupWidth()
    {
        if (!$this->_popupWidth) {
            $this->_popupWidth = $this->scopeConfig->getValue(
                'rendered/popup/popup_width',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_popupWidth;
    }

    /**
     * Get the configured popup height
     *
     * @return string|null
     */
    public function getPopupHeight()
    {
        if (!$this->_popupHeight) {
            $this->_popupHeight = $this->scopeConfig->getValue(
                'rendered/popup/popup_height',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_popupHeight;
    }

    /**
     * Get the configured background color for the popup
     *
     * @return string|null
     */
    public function getBackgroundColor()
    {
        if (!$this->_bgColor) {
            $this->_bgColor = $this->scopeConfig->getValue(
                'rendered/popup/popup_bg',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_bgColor;
    }
}
