<?php

namespace BrightRiver\Rendered\Model\Config\Backend;

/**
 * HEX color code validator.
 *
 * @since 1.0.0
 */
class HexCode extends \Magento\Framework\App\Config\Value
{
    /**
     * Validate a HEX color code field value
     *
     * @return void
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function beforeSave()
    {
        $value = $this->getValue();

        if (!$this->_isValidHex($value)) {
            throw new \Magento\Framework\Exception\LocalizedException(__('Please provide a valid hex code.'));
        }
    }

    /**
     * Validates if the provided string is a valid hex code
     *
     * @param string
     * @return bool
     */
    private function _isValidHex($value)
    {
        if (false === str_starts_with($value, '#')) {
            return false;
        }

        $colorCode = ltrim($value, '#');

        return preg_match('/^([A-Fa-f0-9]{3}){1,2}$/', $colorCode);
    }
}
