<?php

namespace BrightRiver\Rendered\Setup\Patch\Data;

use Magento\Catalog\Model\Product;
use Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Framework\Setup\Patch\PatchVersionInterface;

/**
 * Adds necessary product attributes upon installation.
 *
 * @since 1.0.0
 */
class ConfigureRenderedAttributes implements DataPatchInterface, PatchVersionInterface
{
    /**
     * @var ModuleDataSetupInterface
     */
    private $moduleDataSetup;

    /**
     * @var EavSetupFactory
     */
    private $eavSetupFactory;

    /**
     * ConfigureRenderedAttributes constructor.
     *
     * @param ModuleDataSetupInterface $moduleDataSetup
     * @param EavSetupFactory $eavSetupFactory
     */
    public function __construct(
        ModuleDataSetupInterface $moduleDataSetup,
        EavSetupFactory $eavSetupFactory
    ) {
        $this->moduleDataSetup = $moduleDataSetup;
        $this->eavSetupFactory = $eavSetupFactory;
    }

    /**
     * Retrieve data patch dependencies.
     *
     * @return array
     */
    public static function getDependencies()
    {
        return [];
    }

    /**
     * Retrieve aliases for the data patch.
     *
     * @return array
     */
    public function getAliases()
    {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function apply()
    {
        // Create EAV setup object
        $eavSetup = $this->eavSetupFactory->create(['setup' => $this->moduleDataSetup]);

        // Remove existing Product ID attribute
        $eavSetup->removeAttribute(Product::ENTITY, 'rendered_product_id');

        // Add Product ID attribute
        $eavSetup->addAttribute(
            Product::ENTITY,
            'rendered_product_id',
            [
                'group' => 'Rendered',
                'label' => 'Unique Product ID',
                'type' => 'int',
                'input' => 'text',
                'backend' => '',
                'frontend' => '',
                'class' => '',
                'source' => '',
                'global' => ScopedAttributeInterface::SCOPE_GLOBAL,
                'visible' => true,
                'required' => false,
                'user_defined' => true,
                'default' => '',
                'searchable' => false,
                'filterable' => false,
                'comparable' => false,
                'visible_on_front' => false,
                'used_in_product_listing' => false,
                'unique' => false,
                'apply_to' => '',
                'sort_order' => 10,
            ]
        );

        // Remove existing AR Placement attribute
        $eavSetup->removeAttribute(Product::ENTITY, 'rendered_ar_placement');

        // Add AR Placement attribute
        $eavSetup->addAttribute(
            Product::ENTITY,
            'rendered_ar_placement',
            [
                'group' => 'Rendered',
                'label' => 'AR Placement',
                'type' => 'varchar',
                'input' => 'select',
                'backend' => '',
                'frontend' => '',
                'class' => '',
                'source' => \BrightRiver\Rendered\Model\Config\Source\ARPlacement::class,
                'global' => ScopedAttributeInterface::SCOPE_GLOBAL,
                'visible' => true,
                'required' => false,
                'user_defined' => true,
                'default' => '',
                'searchable' => false,
                'filterable' => false,
                'comparable' => false,
                'visible_on_front' => false,
                'used_in_product_listing' => true,
                'unique' => false,
                'apply_to' => '',
                'sort_order' => 20,
            ]
        );
    }

    /**
     * {@inheritdoc}
     */
    public static function getVersion()
    {
        return '1.0.0';
    }
}
